@@ -1,4 +1,4 @@
-# Copyright (c) 2003-2008 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2010 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 
 # This program is free software; you can redistribute it and/or modify it under
@@ -12,54 +12,38 @@
 
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-"""
-logilab.devtools packaging information
-"""
-
+# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+"""logilab.devtools packaging information"""
 
 modname = 'devtools'
 distname = 'logilab-devtools'
-numversion = (0, 15, 0)
+numversion = (0, 18, 2)
 version = '.'.join([str(num) for num in numversion])
 
 license = 'GPL'
-copyright = '''Copyright (c) 2003-2008 LOGILAB S.A. (Paris, FRANCE).
-http://www.logilab.fr/ -- mailto:contact@logilab.fr'''
-
 author = "Logilab"
 author_email = "contact@logilab.fr"
 
-short_desc = "set of development tools used at Logilab"
-long_desc = """Set of tools which aims to help the developpement process, including :
-* standard for zope and python packages
-* tools to check and build source and/or debian packages
-* python coverage tool
-* cvs/svn utilities
-"""
-web = "http://www.logilab.org/project/devtools"
+description = "set of development tools used at Logilab"
+web = "http://www.logilab.org/project/logilab-devtools"
 ftp = "ftp://ftp.logilab.org/pub/devtools"
 mailinglist = "mailto://python-projects@lists.logilab.org"
 
 subpackage_of = 'logilab'
 
-from os.path import join
+from os.path import join, isdir
 
 include_dirs = ['templates', join('test', 'data')]
 
+if isdir('narval'):
+    data_files = [[join('var', 'lib', 'narval', 'plugins'), [join('narval', 'lgp.py')]]]
+
 scripts = [
-    # vcslib
-    'bin/vcpull',
-    'bin/cvslog',
-    'bin/cvstatus',
-    'bin/hgstatus',
-    # pycovergae
-    'bin/pycoverage',
     # logilab-packaging
     'bin/changelog',
     'bin/update_gettext',
     'bin/lgp',
-    'bin/vbuild',
     'bin/lsprofcalltree',
-    ] 
+    ]
 
+install_requires = ['logilab-common']
