@@ -4,6 +4,6 @@ http://www.logilab.fr/ -- mailto:contact@logilab.fr
 Logilab's developpment tools
 """
 
-from os.path import join
-TEMPLATE_DIR = join(__path__[0], 'templates')
+from os.path import join, dirname
+TEMPLATE_DIR = join(dirname(__file__), 'templates')
 del join
